==> linuxconf_1.17r5.orig.tar.gz: linuxconf-1.17r5/modules/samba/samba.pm <==
/* _dict.cc 07/10/1997 20.14.38 */
/* internal.cc 07/10/1997 12.54.18 */
PUBLIC SAMBA_HELP_FILE::SAMBA_HELP_FILE (const char *fname);
/* keyword.cc 12/12/1999 22.12.46 */
/* samba.cc 12/12/1999 22.12.46 */
PUBLIC MODULE_SAMBA::MODULE_SAMBA (void);
PUBLIC void MODULE_SAMBA::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_SAMBA::domenu (MENU_CONTEXT context, const char *key);
PUBLIC int MODULE_SAMBA::message (const char *msg,
	 int argc,
	 const char *argv[]);
PUBLIC void MODULE_SAMBA::usage (SSTRINGS&tb);
PUBLIC int MODULE_SAMBA::execmain (int argc, char *argv[]);
/* smbconf.cc 23/01/2000 23.04.18 */
PUBLIC SMB_ITEM::SMB_ITEM (void);
PUBLIC SMB_ITEM::SMB_ITEM (const char *_comment, const char *line);
PUBLIC void SMB_ITEM::write (FILE *fout)const;
PUBLIC SMB_ITEM *SMB_ITEMS::getitem (int no)const;
PUBLIC SMB_ITEM *SMB_ITEMS::getitem (const char *key)const;
PUBLIC const char *SMB_ITEMS::getval (const char *key)const;
PUBLIC const char *SMB_ITEMS::getval (const char *key1,
	 const char *key2,
	 const char *key3)const;
PUBLIC void SMB_ITEMS::setval (const char *key, const char *val);
PUBLIC void SMB_ITEMS::setval (const char *key, const SSTRING&val);
PUBLIC void SMB_ITEMS::setval (const char *key, int num);
PUBLIC void SMB_ITEMS::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 const char *val);
PUBLIC void SMB_ITEMS::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 const SSTRING&val);
PUBLIC void SMB_ITEMS::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 int num);
PUBLIC void SMB_ITEMS::write (FILE *fout)const;
PUBLIC SMB_SHARE::SMB_SHARE (const char *_comment, const char *_name);
PUBLIC SMB_SHARE::SMB_SHARE (void);
PUBLIC const char *SMB_SHARE::getval (const char *key)const;
PUBLIC const char *SMB_SHARE::getval (const char *key1,
	 const char *key2,
	 const char *key3)const;
PUBLIC void SMB_SHARE::setval (const char *key, const SSTRING&val);
PUBLIC void SMB_SHARE::setval (const char *key, int num);
PUBLIC void SMB_SHARE::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 const SSTRING&val);
PUBLIC void SMB_SHARE::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 int num);
PUBLIC void SMB_SHARE::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 const char *val);
PUBLIC void SMB_SHARE::write (FILE *fout)const;
PUBLIC SMB_SHARE *SMB_SHARES::getitem (int no)const;
PUBLIC SMB_SHARE *SMB_SHARES::getitem (const char *name)const;
PUBLIC SMB_CONF::SMB_CONF (void);
PUBLIC int SMB_CONF::write (void);
PUBLIC int SMB_CONF::sanitycheck (void);
/* status.cc 28/04/1999 15.53.16 */
/* samedit.cc 23/01/2000 22.58.36 */
PRIVATE void SMB_SHARE::setdia (DIALOG&dia,
	 SMB_FIELD tbf[],
	 int nbf,
	 SMB_FIELD_VAL tbv[]);
PRIVATE void SMB_SHARE::savedia (SMB_FIELD tbf[],
	 int nbf,
	 SMB_FIELD_VAL tbv[]);
PUBLIC int SMB_SHARE::editgen (DIALOG&dia,
	 SMB_FIELD tbf[],
	 int nbf,
	 bool may_del,
	 SAMBA_HELP_FILE&help_file);
PUBLIC int SMB_SHARE::edit (void);
PUBLIC int SMB_SHARE::editglobal (void);
PUBLIC int SMB_SHARE::editnetlogon (SMB_SHARE *glob);
PUBLIC int SMB_SHARE::edithomes (void);
PUBLIC int SMB_SHARE::editprinters (void);
PUBLIC int SMB_SHARES::write (void);
PUBLIC int SMB_CONF::editshares (void);
PUBLIC void SMB_CONF::editdefaults (void);
PUBLIC void SMB_CONF::edithomes (void);
PUBLIC void SMB_CONF::editprinters (void);
PUBLIC void SMB_CONF::editnetlogon (void);
PUBLIC void SMB_CONF::edit (void);

==> linuxconf_1.26r4.orig.tar.gz: linuxconf-1.26r4/modules/samba/samba.pm <==
/* _dict.cc 07/10/1997 20.14.38 */
/* internal.cc 07/10/1997 12.54.18 */
PUBLIC SAMBA_HELP_FILE::SAMBA_HELP_FILE (const char *fname);
/* keyword.cc 29/03/2000 23.51.12 */
/* samba.cc 25/10/2000 14.14.38 */
PUBLIC MODULE_SAMBA::MODULE_SAMBA (void);
PUBLIC void MODULE_SAMBA::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_SAMBA::domenu (MENU_CONTEXT context, const char *key);
PUBLIC int MODULE_SAMBA::message (const char *msg,
	 int argc,
	 const char *argv[]);
PUBLIC void MODULE_SAMBA::usage (SSTRINGS&tb);
PUBLIC int MODULE_SAMBA::execmain (int argc, char *argv[], bool);
/* samedit.cc 18/01/2001 21.29.26 */
PRIVATE void SMB_SHARE::setdia (DIALOG&dia,
	 SMB_FIELD tbf[],
	 int nbf,
	 SMB_FIELD_VAL tbv[]);
PRIVATE void SMB_SHARE::savedia (SMB_FIELD tbf[],
	 int nbf,
	 SMB_FIELD_VAL tbv[]);
PUBLIC int SMB_SHARE::editgen (DIALOG&dia,
	 SMB_FIELD tbf[],
	 int nbf,
	 bool may_del,
	 SAMBA_HELP_FILE&help_file);
PUBLIC int SMB_SHARE::edit (void);
PUBLIC int SMB_SHARE::editglobal (SMB_CONF *samba);
PUBLIC int SMB_SHARE::editnetlogon (SMB_SHARE *glob, SMB_CONF *samba);
PUBLIC int SMB_SHARE::edithomes (SMB_CONF *samba);
PUBLIC int SMB_SHARE::editprinters (SMB_CONF *samba);
PUBLIC int SMB_SHARES::write (void);
PUBLIC int SMB_CONF::editshares (void);
PUBLIC void SMB_CONF::editdefaults (void);
PUBLIC void SMB_CONF::edithomes (void);
PUBLIC void SMB_CONF::editprinters (void);
PUBLIC void SMB_CONF::editnetlogon (void);
PUBLIC void SMB_CONF::edit (void);
/* smbconf.cc 07/08/2000 00.23.48 */
PUBLIC SMB_ITEM::SMB_ITEM (void);
PUBLIC SMB_ITEM::SMB_ITEM (const char *_comment, const char *line);
PUBLIC void SMB_ITEM::write (FILE_CFG *fout)const;
PUBLIC SMB_ITEM *SMB_ITEMS::getitem (int no)const;
PUBLIC SMB_ITEM *SMB_ITEMS::getitem (const char *key)const;
PUBLIC const char *SMB_ITEMS::getval (const char *key)const;
PUBLIC const char *SMB_ITEMS::getval (const char *key1,
	 const char *key2,
	 const char *key3)const;
PUBLIC void SMB_ITEMS::setval (const char *key, const char *val);
PUBLIC void SMB_ITEMS::setval (const char *key, const SSTRING&val);
PUBLIC void SMB_ITEMS::setval (const char *key, int num);
PUBLIC void SMB_ITEMS::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 const char *val);
PUBLIC void SMB_ITEMS::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 const SSTRING&val);
PUBLIC void SMB_ITEMS::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 int num);
PUBLIC void SMB_ITEMS::write (FILE_CFG *fout)const;
PUBLIC SMB_SHARE::SMB_SHARE (const char *_comment, const char *_name);
PUBLIC SMB_SHARE::SMB_SHARE (void);
PUBLIC const char *SMB_SHARE::getval (const char *key)const;
PUBLIC const char *SMB_SHARE::getval (const char *key1,
	 const char *key2,
	 const char *key3)const;
PUBLIC void SMB_SHARE::setval (const char *key, const SSTRING&val);
PUBLIC void SMB_SHARE::setval (const char *key, int num);
PUBLIC void SMB_SHARE::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 const SSTRING&val);
PUBLIC void SMB_SHARE::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 int num);
PUBLIC void SMB_SHARE::setval (const char *key1,
	 const char *key2,
	 const char *key3,
	 const char *val);
PUBLIC void SMB_SHARE::write (FILE_CFG *fout)const;
PUBLIC SMB_SHARE *SMB_SHARES::getitem (int no)const;
PUBLIC SMB_SHARE *SMB_SHARES::getitem (const char *name)const;
PUBLIC SMB_SHARES::SMB_SHARES (SMB_CONF *_samba);
PUBLIC SMB_CONF::SMB_CONF (void);
PUBLIC int SMB_CONF::write (void);
PUBLIC int SMB_CONF::sanitycheck (void);
/* status.cc 28/04/1999 15.53.16 */
